@@ -19,13 +19,21 @@ module.exports = async function (source, options) {
   // https://github.com/babel/babel/blob/main/packages/babel-core/src/transformation/index.js
   // For discussion on this topic see here:
   // https://github.com/babel/babel-loader/pull/629
-  const { ast, code, map, metadata, sourceType } = result;
+  const { ast, code, map, metadata, sourceType, externalDependencies } = result;
 
   if (map && (!map.sourcesContent || !map.sourcesContent.length)) {
     map.sourcesContent = [source];
   }
 
-  return { ast, code, map, metadata, sourceType };
+  return {
+    ast,
+    code,
+    map,
+    metadata,
+    sourceType,
+    // Convert it from a Set to an Array to make it JSON-serializable.
+    externalDependencies: Array.from(externalDependencies || []),
+  };
 };
 
 module.exports.version = babel.version;
